@@ -5,6 +5,8 @@ import configparser
 import logging
 import re
 import sys
+from functools import partial
+from itertools import takewhile
 from pathlib import Path
 from typing import Callable, Iterable, Iterator, NamedTuple, Optional, Tuple
 
@@ -28,6 +30,13 @@ else:
 logger = logging.getLogger(__name__)
 
 ERROR_MESSAGE_TEMPLATE = "Failed to %s %s %s dependencies in %s: %s"
+# https://pip.pypa.io/en/stable/reference/requirements-file-format/#per-requirement-options
+PER_REQUIREMENT_OPTIONS = [
+    "--install-option",
+    "--global-option",
+    "config-setting",
+    "--hash",
+]
 
 NamedLocations = Iterator[Tuple[str, Location]]
 
@@ -42,7 +51,9 @@ class DependencyParsingError(Exception):
 
 def parse_one_req(req_text: str, source: Location) -> DeclaredDependency:
     """Returns the name of a dependency declared in a requirement specifier."""
-    return DeclaredDependency(Requirement.parse(req_text).unsafe_name, source)
+    req = Requirement.parse(req_text)
+    req_name = req.unsafe_name
+    return DeclaredDependency(req_name, source)
 
 
 def parse_requirements_contents(
@@ -54,14 +65,27 @@ def parse_requirements_contents(
     Requirements File Format as documented here:
     https://pip.pypa.io/en/stable/reference/requirements-file-format/.
     """
+    parse_one = partial(parse_one_req, source=source)
     for line in text.splitlines():
+        cleaned = line.lstrip()
         if (
-            not line.lstrip()  # skip empty lines
-            or line.lstrip().startswith(("-", "#"))  # skip options and comments
+            not cleaned  # skip empty lines
+            or cleaned.startswith(("-", "#"))  # skip options and comments
             or ("://" in line.split()[0])  # skip bare URLs at the start of line
         ):
             continue
-        yield parse_one_req(line, source)
+        try:
+            yield parse_one(line)
+        except ValueError:
+            # Try again with the initial part of the line preceding any of the
+            # PER_REQUIREMENT_OPTIONS
+            pre_opt_words = takewhile(
+                lambda word: not any(
+                    word.startswith(opt) for opt in PER_REQUIREMENT_OPTIONS
+                ),
+                cleaned.split(),
+            )
+            yield parse_one(" ".join(pre_opt_words))
 
 
 def parse_setup_contents(text: str, source: Location) -> Iterator[DeclaredDependency]:
