@@ -1,16 +1,13 @@
 """Find undeclared and/or unused 3rd-party dependencies in your Python project.
 
-* Supported files for Python code containing third-party imports:
-  * Python scripts with filenames that end in `.py`
-  * Jupyter notebooks with filenames that end in `.ipynb`
+Supports finding 3rd-party imports in Python scripts (*.py) and Jupyter
+notebooks (*.ipynb).
 
-* Supported files/formats for dependency declarations:
-  * `*requirements*.txt` and `*requirements*.in`
-  * `pyproject.toml` (following PEP 621 or Poetry conventions)
-  * `setup.py` (only limited support for simple files with a single `setup()`
-    call and no computation involved for setting the `install_requires` and
-    `extras_require` arguments)
-  * `setup.cfg`
+Supports finding dependency declarations in *requirements*.txt (and .in) files,
+pyproject.toml (following PEP 621 or Poetry conventions), setup.cfg, as well as
+limited support for setup.py files with a single, simple setup() call and
+minimal computation involved in setting the install_requires and extras_require
+arguments.
 """
 
 import json
@@ -27,7 +24,13 @@ from pydantic.json import custom_pydantic_encoder  # pylint: disable=no-name-in-
 from fawltydeps import extract_imports
 from fawltydeps.check import compare_imports_to_dependencies
 from fawltydeps.extract_declared_dependencies import extract_declared_dependencies
-from fawltydeps.settings import Action, OutputFormat, Settings, setup_cmdline_parser
+from fawltydeps.settings import (
+    Action,
+    OutputFormat,
+    Settings,
+    print_toml_config,
+    setup_cmdline_parser,
+)
 from fawltydeps.types import (
     DeclaredDependency,
     ParsedImport,
@@ -143,13 +146,14 @@ class Analysis:
                 print("\n".join(sorted(unique_dependencies)), file=out)
 
         if self.is_enabled(Action.REPORT_UNDECLARED) and self.undeclared_deps:
-            print("These imports appear to be undeclared dependencies:", file=out)
+            print("\nThese imports appear to be undeclared dependencies:", file=out)
             for undeclared in self.undeclared_deps:
                 print(f"- {undeclared.render(details)}", file=out)
 
         if self.is_enabled(Action.REPORT_UNUSED) and self.unused_deps:
             print(
-                "These dependencies appear to be unused (i.e. not imported):", file=out
+                "\nThese dependencies appear to be unused (i.e. not imported):",
+                file=out,
             )
             for unused in self.unused_deps:
                 print(f"- {unused.render(details)}", file=out)
@@ -171,12 +175,22 @@ def main() -> int:
         default=Path("./pyproject.toml"),
         help="Where to find FawltyDeps config (default: ./pyproject.toml)",
     )
+    option_group.add_argument(
+        "--generate-toml-config",
+        action="store_true",
+        default=False,
+        help="Print a TOML config section with the current settings, and exit",
+    )
 
     args = parser.parse_args()
     settings = Settings.config(config_file=args.config_file).create(args)
 
     logging.basicConfig(level=logging.WARNING - 10 * settings.verbosity)
 
+    if args.generate_toml_config:
+        print_toml_config(settings, sys.stdout)
+        return 0
+
     try:
         analysis = Analysis.create(settings)
     except UnparseablePathException as exc:
